pub(super) fn is_only_sisu_timeouts<'a>(
endpoint: SuotarEndpoint,
codes: impl IntoIterator<Item = &'a str>,
) -> boolExpand description
Whether every item code of an answer says Sisu timed out: Suotar itself answered.
pub(super) fn is_only_sisu_timeouts<'a>(
endpoint: SuotarEndpoint,
codes: impl IntoIterator<Item = &'a str>,
) -> boolWhether every item code of an answer says Sisu timed out: Suotar itself answered.